@@ -1,18 +1,11 @@
-from django.db import models
-from django.conf import settings
 from django.contrib.auth.models import Permission
-from django.utils.translation import ugettext_lazy as _
+from django.db import models
 from django.utils.encoding import python_2_unicode_compatible
+from django.utils.translation import ugettext_lazy as _
 
 from .settings import MODEL_TREE, TREE_ITEMS_ALIASES
 
 
-# This allows South to handle our custom 'CharFieldNullable' field.
-if 'south' in settings.INSTALLED_APPS:
-    from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ['^sitetree\.models\.CharFieldNullable'])
-
-
 class CharFieldNullable(models.CharField):
     """We use custom char field to put nulls in SiteTreeItem 'alias' field.
     That allows 'unique_together' directive in Meta to work properly, so
@@ -74,7 +67,7 @@ class TreeItemBase(models.Model):
                     '<b>Note:</b> Refer to Django "URL dispatcher" documentation (e.g. "Naming URL patterns" part).'),
         db_index=True, default=False)
     tree = models.ForeignKey(
-        MODEL_TREE, related_name='%(class)s_tree', verbose_name=_('Site Tree'),
+        MODEL_TREE, related_name='%(class)s_tree', on_delete=models.CASCADE, verbose_name=_('Site Tree'),
         help_text=_('Site tree this item belongs to.'), db_index=True)
     hidden = models.BooleanField(
         _('Hidden'), help_text=_('Whether to show this item in navigation.'), db_index=True, default=False)
@@ -118,7 +111,7 @@ class TreeItemBase(models.Model):
     # These two are for 'adjacency list' model.
     # This is the current approach of tree representation for sitetree.
     parent = models.ForeignKey(
-        'self', related_name='%(class)s_parent', verbose_name=_('Parent'),
+        'self', related_name='%(class)s_parent', on_delete=models.CASCADE, verbose_name=_('Parent'),
         help_text=_('Parent site tree item.'), db_index=True, null=True, blank=True)
     sort_order = models.IntegerField(
         _('Sort order'),
