@@ -1,5 +1,7 @@
 #! /usr/bin/env python
 
+import sys
+
 if __name__ == '__main__':
     from pytest import main as pytest_main
-    pytest_main()
+    sys.exit(pytest_main())
