@@ -1,20 +1,12 @@
+from importlib import import_module
+
+from django.apps import apps
 from django.contrib.auth.models import Permission
 from django.core.exceptions import ImproperlyConfigured
 from django.utils import six
 from django.utils.module_loading import module_has_submodule
 
-try:
-    from importlib import import_module
-except ImportError:  # Python < 2.7
-    from django.utils.importlib import import_module
-
-try:
-    from django.apps import apps
-    apps_get_model = apps.get_model
-except ImportError:  # Django < 1.7
-    from django.db.models import get_model
-    apps_get_model = None
-
+apps_get_model = apps.get_model
 
 from sitetree import settings
 
@@ -175,13 +167,11 @@ def get_model_class(settings_entry_name):
     :rtype: TreeItemBase|TreeBase
     """
     app_name, model_name = get_app_n_model(settings_entry_name)
-    if apps_get_model is None:
-        model = get_model(app_name, model_name)
-    else:
-        try:
-            model = apps_get_model(app_name, model_name)
-        except (LookupError, ValueError):
-            model = None
+
+    try:
+        model = apps_get_model(app_name, model_name)
+    except (LookupError, ValueError):
+        model = None
 
     if model is None:
         raise ImproperlyConfigured(
